ApiBuilderSimple

Struct ApiBuilderSimple 

pub struct ApiBuilderSimple { /* private fields */ }
The Simple Builder is not limited to what is within Enums, so the builder SHOULD be able to deal with any arbitrary data. If the user uses something unsupported, breakage MIGHT occur, but at the same time should something unsupported and new or shiny happen, the user can use it.

Implementations

Source

impl ApiBuilderSimple

pub fn new() -> Self

pub fn base_url(&mut self, base_url: String) -> &mut Self

pub fn questions(&mut self, questions: u8) -> &mut Self

pub fn category(&mut self, category: u8) -> &mut Self

pub fn difficulty(&mut self, difficulty: String) -> &mut Self

pub fn question_type(&mut self, question_type: String) -> &mut Self

pub fn encoding(&mut self, encoding: String) -> &mut Self

pub fn token(&mut self, token: String) -> &mut Self

pub fn build(&self) -> ApiRequest