pub enum QuestionType {
All,
Multiple,
Boolean,
}Expand description
The Question Type is what describes what sort of question type this is.
The “Multiple” question type will give multiple-choice questions, where there is one correct answer and multiple incorrect ones.
The “Boolean” question type will give you true/false questions.
Variants
All
Do not filter question types
Multiple
Filter by Multiple Choice questions
Boolean
Filter by true/false questions
Implementations